@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package DNS::Oterica::RecordMaker::TinyDNS;
 # ABSTRACT: a tinydns recordmaker for DNSO.
-$DNS::Oterica::RecordMaker::TinyDNS::VERSION = '0.206';
+$DNS::Oterica::RecordMaker::TinyDNS::VERSION = '0.303';
 #pod =head1 DESCRIPTION
 #pod
 #pod This role provides logic for generating lines for the F<tinydns-data> program
@@ -379,7 +379,7 @@ sub dkim {
 
   # We can't use ->txt because tinydns will split TXT records (generated by ')
   # up into 127b chunks.  DKIM doesn't let you do that. -- rjbs, 2016-10-04
-  return sprintf ':%s:16:\\%03o%s:%s',
+  return sprintf ":%s:16:\\%03o%s:%s\n",
     $name,
     length($text),
     _colon_safe($text),
@@ -400,7 +400,7 @@ DNS::Oterica::RecordMaker::TinyDNS - a tinydns recordmaker for DNSO.
 
 =head1 VERSION
 
-version 0.206
+version 0.303
 
 =head1 DESCRIPTION
 
